/*
 * 
 * Dispensacion_runtinas
 * 
 * 
 * (C) Alvaro Cortes. 2007. alvarocortesc@gmail.com
 * 
 * 
 * Contiene las rutinas de bajo nivel necesarias para el modulo de dispensacion.
 * 
 */

using System;
using System.Data;
using MySql.Data.MySqlClient;
using System.Collections;

namespace FormulacionMagistral
{
	/// <summary>
	/// Description of Dispensacion_rutinas.
	/// </summary>
	public class Dispensacion_rutinas
	{
		
		
		/// <summary>
		/// Obtiene los honorarios profesionales correspondientes
		/// segun provincia, ao, tipo de formula y cantidad.
		/// </summary>
		/// <param name="strconn">Cadena de conexion con la BD</param>
		/// <param name="provincia">Provincia donde se tasa</param>
		/// <param name="annus">Ao para tasacion</param>
		/// <param name="tipoid">Tipo de formula</param>
		/// <param name="cantidad">Cantidad de formula</param>
		/// <returns>Devuelve los honorarios sin aplicar el factor P</returns>
		public static float get_honorarios(string strconn, string provincia, string annus, int tipoid, float cantidad){
			
			MySqlConnection conexion;
			MySqlDataReader MyLector = null;
			MySqlCommand MyCmd;
			float unidad = 0;

			try{
				conexion = new MySqlConnection(strconn);
				conexion.Open();
			
				MyCmd = new MySqlCommand("SELECT * FROM tasacion_"+provincia+"_"+annus+" WHERE TipoCompuestoID=" + tipoid.ToString() +" AND tramo_min <=" + cantidad.ToString() + " AND tramo_max >= " + cantidad.ToString() + ";",conexion);
				MyLector = MyCmd.ExecuteReader();
				if ( MyLector.Read() ) // Si hay registros es que hay un tramo de la formulacion
				{
					unidad = MyLector.GetFloat(4);
				}
				conexion.Close();
				
				return (float) (cantidad * unidad);
			}catch(Exception e){
			FM_Errores.MostrarError("get_honorarios","No se puede establecer la conexion con la base de datos",e);
			return (float) 0;
			}

			
		}
		
		/// <summary>
		/// Obtiene los honorarios profesionales correspondientes
		/// segun provincia, ao, tipo de formula y cantidad.
		/// </summary>
		/// <param name="strconn">Cadena de conexion con la BD</param>
		/// <param name="provincia">Provincia donde se tasa</param>
		/// <param name="annus">Ao para tasacion</param>
		/// <param name="tipoid">Tipo de formula</param>
		/// <param name="cantidad">Cantidad de formula</param>
		/// <returns>Devuelve los honorarios sin aplicar el factor P</returns>
		public static float get_honorarios(string strconn, string provincia, string annus, string tipoid, float cantidad){
			
			MySqlConnection conexion;
			MySqlDataReader MyLector = null;
			MySqlCommand MyCmd;
			int id1;
			float unidad = 0;
				
			try{
				id1 = get_formulaid(strconn, tipoid);
			conexion = new MySqlConnection(strconn);
			conexion.Open();
				MyCmd = new MySqlCommand("SELECT * FROM tasacion_"+provincia+"_"+annus+" WHERE TipoCompuestoID=" + id1.ToString() +" AND tramo_min <=" + cantidad.ToString() + " AND tramo_max >= " + cantidad.ToString() + ";",conexion);
				MyLector = MyCmd.ExecuteReader();
				if ( MyLector.Read() ) // Si hay registros es que hay un tramo de la formulacion
				{
					unidad = MyLector.GetFloat(3);
				}
				conexion.Close();
				
				return (float) (cantidad * unidad);
			}catch(Exception e){
			FM_Errores.MostrarError("get_honorarios","No se puede establecer la conexion con la base de datos",e);
			return (float) 0;
			}

			
		}
		
		
		
		
		
		/// <summary>
		/// Obtiene el precio del envase solicitido
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <param name="envaseid">ID del envase</param>
		/// <param name="provincia">Provincia actual</param>
		/// <param name="annus">Ao actual</param>
		/// <returns>Devuelve el valor del envase en tipo float</returns>
		public static float get_precio_envase(string strconn, string provincia, string annus, int envaseid){
			
			MySqlConnection conexion;
			MySqlDataReader MyLector = null;
			MySqlCommand MyCmd;
			float precio = 0;

			try{
				conexion = new MySqlConnection(strconn);
				conexion.Open();
			
				MyCmd = new MySqlCommand("SELECT * FROM envases_"+provincia+"_"+annus+" WHERE EnvaseID=" + envaseid.ToString() + ";",conexion);
				MyLector = MyCmd.ExecuteReader();
				if ( MyLector.Read() ) // Si hay registros es que hay un tramo de la formulacion
				{
					precio = MyLector.GetFloat(2);
				}
				conexion.Close();
				
				return (float) precio;
			}catch(Exception e){
			FM_Errores.MostrarError("get_precio_envase","No se puede establecer la conexion con la base de datos",e);
			return (float) 0;
			}

			
			
		}
		
		
		/// <summary>
		/// Obtiene los datos del componente especificado por id
		/// </summary>
		/// <param name="strconn">Cadena de conexion con la BD</param>
		/// <param name="compid">ID del componente</param>
		/// <returns>Devuelve un string[] con los siguientes datos: 0-Nombre, 1-Unidades</returns>
		public static string[] get_componente_details(string strconn, int compid){
			
			MySqlConnection conexion;
			MySqlDataReader MyLector = null;
			MySqlCommand MyCmd;
			string[] res = {"",""};
			int unidadid = 0;

			try{
				conexion = new MySqlConnection(strconn);
				conexion.Open();
			
				MyCmd = new MySqlCommand("SELECT * FROM materia WHERE MateriaID=" + compid.ToString() +";",conexion);
				MyLector = MyCmd.ExecuteReader();
				if ( MyLector.Read() ) 
				{
					res[0] = MyLector.GetString(1); // DOE
				}

				MyLector.Close();
				MyCmd = new MySqlCommand("SELECT * FROM especificaciones WHERE MateriaID=" + compid.ToString() +";",conexion);
				MyLector = MyCmd.ExecuteReader();
				if ( MyLector.Read() ) 
				{
					unidadid = MyLector.GetInt32(1); // ID de Unidades
				}
				MyLector.Close();

				MyCmd = new MySqlCommand("SELECT * FROM unidades WHERE UnidadID=" + unidadid.ToString() +";",conexion);
				MyLector = MyCmd.ExecuteReader();
				if ( MyLector.Read() ) 
				{
					res[1] = MyLector.GetString(2); // Abreviatura de unidades
				}
				MyLector.Close();
				
				conexion.Close();
				
				return res;
			}catch(Exception e){
			FM_Errores.MostrarError("get_componente_details","No se puede establecer la conexion con la base de datos",e);
			return res;
			}

			
		}

		/// <summary>
		/// Obtiene los datos del componente especificado por id
		/// </summary>
		/// <param name="strconn">Cadena de conexion con la BD</param>
		/// <param name="compid">ID del componente</param>
		/// <returns>Devuelve el precio del componente</returns>
		public static float get_componente_precio(string strconn, int compid){
			
			MySqlConnection conexion;
			MySqlDataReader MyLector = null;
			MySqlCommand MyCmd;
			float precio = 0;

			try{
				conexion = new MySqlConnection(strconn);
				conexion.Open();
			
				MyCmd = new MySqlCommand("SELECT * FROM especificaciones WHERE MateriaID=" + compid.ToString() +";",conexion);
				MyLector = MyCmd.ExecuteReader();
				if ( MyLector.Read() ) 
				{
					precio = MyLector.GetFloat(10); // Precio
				}
				MyLector.Close();
				
				conexion.Close();
				
				return precio;
			}catch(Exception e){
			FM_Errores.MostrarError("get_componente_precio","No se puede establecer la conexion con la base de datos",e);
			return precio;
			}

			
		}
		
		
		/// <summary>
		/// Devuelve el ID del tipo de formula asociado
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <param name="tipoid">Nombre del tipo de formulacion</param>
		/// <returns>Entero que identifica al tipo en la base de datos</returns>
		public static int get_formulaid(string strconn, string tipoid){
			
			MySqlConnection conexion;
			MySqlDataReader MyLector = null;
			MySqlCommand MyCmd;
			int id1 = 0;
				try{
				conexion = new MySqlConnection(strconn);
				conexion.Open();
				
				MyCmd = new MySqlCommand("SELECT * FROM tipos_compuesto WHERE Nombre = '" + tipoid+"'",conexion);
				MyLector = MyCmd.ExecuteReader();
				if ( MyLector.Read() ) // Si hay registros es que hay un compuesto
				{
					id1 = MyLector.GetInt32(0);
				}
				conexion.Close();
				return id1;
			}catch(Exception ex){
				FM_Errores.MostrarError("get_formulaid","No se puede obtener el identificador del tipo de formulacion",ex);
				return id1;
			}
			
		}
		
		
		/// <summary>
		/// Devuelve el nombre completo del paciente
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <param name="pacid">ID del paciente</param>
		/// <returns>Devuelve Nombre completo del paciente</returns>
		public static string get_paciente(string strconn, string pacid){
			
			MySqlConnection conexion;
			MySqlDataReader MyLector = null;
			MySqlCommand MyCmd;
			string nombre = "";
				try{
				conexion = new MySqlConnection(strconn);
				conexion.Open();
				
				MyCmd = new MySqlCommand("SELECT * FROM pacientes WHERE PacienteID = " + pacid+"",conexion);
				MyLector = MyCmd.ExecuteReader();
				if ( MyLector.Read() ) // Si hay registros es que hay un paciente
				{
					nombre = MyLector.GetString(1) + " " + MyLector.GetString(2);
				}
				conexion.Close();
				return nombre;
			}catch(Exception ex){
				FM_Errores.MostrarError("get_paciente","No se puede obtener el nombre del paciente",ex);
				return nombre;
			}
			
		}
				
		
		/// <summary>
		/// Obtiene una lista de los tipos de formulacion ordenadas por ID
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <returns></returns>
		public static string[] get_list_typeformulas(string strconn){
		
		ArrayList compuestos = new ArrayList();
		MySqlCommand MyCmd;
		MySqlConnection conexion;
		MySqlDataReader MyLector;
		
		try{
			conexion = new MySqlConnection(strconn);
			conexion.Open();
		
				MyCmd = new MySqlCommand("SELECT * FROM tipos_compuesto ORDER BY TipoCompuestoID",conexion);
				MyLector = MyCmd.ExecuteReader();
			while( MyLector.Read() )
				compuestos.Add(MyLector.GetString(1));
		MyLector.Close();
		
		return (string[])compuestos.ToArray(typeof(string));
		}catch(MySqlException e){
			FM_Errores.MostrarError("get_list_typeformulas","Error relacionado con la base de datos",e);
			return (string[])compuestos.ToArray(typeof(string));
		}catch(Exception err){
			FM_Errores.MostrarError("get_list_typeformulas","Error obteniendo lista de tipos de compuestos",err);
			return (string[])compuestos.ToArray(typeof(string));
		}
			
		}

		
		
	}
}
