/*
 *
 *
 *	Errores.cs
 *
 *	(C) 2006. Alvaro Cortes
 *
 *	Controla los errores que se producen en todos los modulos
 *	del programa.
 *
 *
 */

 using System.Windows.Forms;
 
/// <summary>
/// Clase encargada de la gestion de errores producidos a lo largo
/// de la aplicacion.
/// </summary>
class FM_Errores{

	#region Mtodos de aviso de errores
	/// <summary>
	/// Muestra el error indicado segun un formato estandar que permita
	/// la rapida identificacion del modulo que origino el error.
	/// </summary>
	/// <param name="strTitulo">Nombre del modulo donde se origino el error</param>
	/// <param name="mensaje">Mensaje de error a comunicar</param>
	/// <param name="e">Objeto de tipo System.Exception para mostrar la traza del error.</param>
	public static void MostrarError(string strTitulo, 
			string mensaje, System.Exception e){
		/*System.Console.WriteLine("{0}: {1}.",strTitulo, mensaje);
		System.Console.WriteLine("Traza:\n" + e.Message);*/
		MessageBox.Show(mensaje,"Error en: " + strTitulo);
		MessageBox.Show(e.Message,"Traza del error");
	}

	/// <summary>
	/// Muestra el error indicado segun un formato, pero sin traza
	/// </summary>
	/// <param name="strTitulo">Origen del error</param>
	/// <param name="mensaje">Mensaje explicativo</param>
	public static void MostrarError(string strTitulo,string mensaje){
		MessageBox.Show(mensaje,"Error en: " + strTitulo);
	}
	/// <summary>
	/// Muestra un error indicado sin titulo y sin traza
	/// </summary>
	/// <param name="mensaje">Mensaje explicativo</param>
	public static void MostrarError(string mensaje){
		MessageBox.Show(mensaje,"Error");
	}
	#endregion
	
	#region Mtodos de aviso de avisos (valga la redundancia)
	/// <summary>
	/// Muestra un aviso segun un formato definido
	/// </summary>
	/// <param name="strTitulo">Origen del aviso</param>
	/// <param name="mensaje">Mensaje de aviso</param>
	public static void MostrarAviso(string strTitulo, string mensaje){
	
		MessageBox.Show(mensaje,strTitulo);
		//System.Console.WriteLine("{0}: {1}.",strTitulo,mensaje);
	}
	
	/// <summary>
	/// Muestra un aviso proporcionando el mensaje
	/// </summary>
	/// <param name="mensaje">Mensaje a mostrar</param>
	public static void MostrarAviso(string mensaje){
		MessageBox.Show(mensaje,"Aviso");
	}
	#endregion
}
