/*
 *
 * 	(C) 2006. Alvaro Corts.
 *
 *	Modulo de autentificacion de usuarios.
 *
 */

using System;
using MySql.Data.MySqlClient;
using System.Security.Cryptography;
using System.Text;
using System.Collections;
using System.Windows.Forms;

namespace Formulacion
{

	/// <summary>
	/// Carga de la base de datos las preferencias de la interfaz de usuario
	/// </summary>
	public class FarmaAuthorize
	{
	private	MySqlConnection conexion;
	private string cadenaConexion;

		#region Constructor

		/// <summary>
		/// Construye una clase de autentificacion para el programa.
		/// </summary>
		public FarmaAuthorize()
		{
		}

		#endregion

		#region Asignadores de propiedades

		/// <summary>
		/// Asigna lo parametros de conexion con la base de datos
		/// para la autentificacion de usuario.
		/// </summary>
		/// <param name="host">Nombre o IP del servidor</param>
		/// <param name="port">Puerto de conexion</param> 
		/// <param name="user">Usuario de la BD</param>
		/// <param name="passwd">Password para el usuario</param>
		/// <param name="database">Base de datos del servidor</param>
		/// <returns>Devuelve nada.</returns>
		public void setConnectionParameters(string host, string port, string user, string passwd, string database){
		cadenaConexion = "server="+host+";port="+ port +";user id="+user+";password="+passwd + ";database="+database+";pooling=false";
		}

#endregion

		#region Mtodo publicos

		/// <summary>
		/// Obtiene el hash MD5 de una cadena.
		/// </summary>
		/// <param name="cadena">Cadena a convertir</param>
		/// <returns>Devuelve el hash MD5</returns>
		public string ConvertiraMd5 (string cadena)
           	{
                 MD5 md5 = MD5CryptoServiceProvider.Create();
                 byte[] dataMd5 = md5.ComputeHash(Encoding.Default.GetBytes(cadena));
                 StringBuilder construyecadena = new StringBuilder();
                 for (int i = 0; i < dataMd5.Length; i++)
                       construyecadena.AppendFormat("{0:x2}", dataMd5[i]);
                 return construyecadena.ToString();
           	}

		
		/// <summary>
		/// Establece la conexion con la base de datos segun los 
		/// parametros asignados.
		/// </summary>
		/// <returns>Devuelve true si no hay error o false si existe algun problema</returns>
		private bool conectar(){
			try{
			conexion = new MySqlConnection(cadenaConexion);
			conexion.Open();
			return true;
			}catch(Exception e){
			FM_Errores.MostrarError("conectar","No se puede establecer la conexion con la base de datos",e);
			return false;
			}
		}

		/// <summary>
		/// Desconecta del servidor
		/// </summary>

		private void desconectar(){
			conexion.Close();
		}

		/// <summary>
		/// Autentifica los usuarios en la base de datos
		/// </summary>
		/// <param name="user">Nombre de usuario</param>
		/// <param name="passwd">Contrasea</param>
		/// <param name="instancia">Nuemero de la instancia del programa</param>
		///<example>Ejemplo de uso de login.
		///<code>
		/// class Miclase
		/// {
		/// 	static void Main()
		/// 	{
		///		FarmaAuthorize sec = new FarmaAuthorize();
		///		sec.setConnectionParameters("localhost","3306","user","pasoteword","mysql");
		///		if ( sec.login("usuario","pasoteword","23434") )
		///		  System.Console.WriteLine("OK");
		///		else
		///		  System.Console.WriteLine("Fail");
		///	}
		/// }
		/// </code>
		/// </example>
		/// <returns>Devuelve verdadero si ha tenido exito</returns>
		public bool login(string user, string passwd, int instancia)
		{	
			string hashpasswd;
			int nivel;
			MySqlDataReader MyLector = null;
			MySqlCommand MyCmd;

			hashpasswd = ConvertiraMd5(passwd); // Obtiene el hash MD5 de la contrasea
			
			user.Replace("\'",""); // Quita la comillas simples que podrian usarse en ataques SQL Injection y eso.
			
			try 
			{
				if ( this.conectar() )
				{
				MyCmd = new MySqlCommand("SELECT * FROM personal WHERE usuario='" + user +"' AND pasoteword='" + hashpasswd + "';",conexion);
				MyLector = MyCmd.ExecuteReader();
				if ( MyLector.Read() ) // Si hay registros es que hay un usuario
				{
				nivel = MyLector.GetInt32(1);
				this.desconectar();
				// Se registra en la tabla el usuario, la instacia y el nivel para
				// que el resto del programa pueda acceder a ello cuando lo necesite
				if( Registra_login(user,instancia,nivel) )  
				return true;
				else
				return false;
				}else{
				this.desconectar();
				return false;
				}
				}else{
				return false;
				}
			}catch (MySqlException ex) 
			{
			FM_Errores.MostrarError("login","Error relacionado con la base de datos",ex);
				return false;
			}catch(Exception ete){
			FM_Errores.MostrarError("login","Error autentificado al usuario",ete);
				return false;
			}
		}
		
		/// <summary>
		/// Registra un nuevo usuario en la base de datos
		/// </summary>
		/// <param name="username">Nombre usuario</param>
		/// <param name="passwd">Contrasea</param>
		/// <param name="avatar">Imagen</param>
		/// <param name="level">Tipo de usuario en entero</param>
		/// <param name="Nombre">Nombre real</param>
		/// <param name="Apellidos">Apellidos</param>
		/// <param name="caducidad">String con la caducidad del usuario</param>
		/// <returns>Devuelve verdadero si ha tenido exito</returns>
		public bool CreateNewUser(string username, string passwd, string avatar, int level, string Nombre, string Apellidos, string caducidad){
		string pasotehash;
		MySqlCommand MyCmd;

		try{
		pasotehash = ConvertiraMd5(passwd); // Obtiene el hash md5
		
		username.Replace("\'","");
		avatar.Replace("\'","");
		Nombre.Replace("\'","");
		Apellidos.Replace("\'","");
		caducidad.Replace("\'","");
		
		if ( this.conectar() )
		{
		MyCmd = new MySqlCommand("INSERT INTO personal (usuario,pasoteword,avatar,TipoID,Nombre,Apellidos) VALUES ('" + username +"','" + pasotehash + "','" + avatar + "','" + level + "','" + Nombre + "','" + Apellidos +"') ",conexion);
		MyCmd.ExecuteNonQuery();
		this.desconectar();
		return true;
		}else{
		return false;
		}
		}catch(MySqlException e){
			FM_Errores.MostrarError("CreateNewUser","Error relacionado con la base de datos",e);
			return false;
		}catch(Exception err){
			FM_Errores.MostrarError("CreateNewUser","Error creando un nuevo usuario",err);
			return false;
		}
		}

		/// <summary>
		/// Registra el nombre de usuario y la instancia que lo autentifico
		/// </summary>
		/// <param name="username">Nombre de usuario</param>
		/// <param name="appid">Id aleatorio generado por el programa</param>
		/// <param name="level">Nivel de restriccion del usuario</param>
		/// <returns>Devuelve verdadero si ha tenido exito</returns>
		private bool Registra_login(string username, int appid, int level){
		
		MySqlCommand MyCmd;

		try{
		if( this.conectar() )
		{
			username.Replace("\'","");
		MyCmd = new MySqlCommand("INSERT INTO logusers (username, instance, level) VALUES ('" + username + "','" + appid + "','"+ level +"')",conexion);
		MyCmd.ExecuteNonQuery();
		this.desconectar();
		return true;
		}else{
		return false;
		}
		}catch(MySqlException e){
			FM_Errores.MostrarError("Registra_login","Error relacionado con la base de datos",e);
			return false;
		}catch(Exception err){
			FM_Errores.MostrarError("Registra_login","Error registrando el usuario conectado",err);
			return false;
		}

		}
		
		/// <summary>
		/// Borra de la lista de usuarios conectados el usuario
		/// especificado.
		/// </summary>
		/// <param name="username">Nombre del usuario conectado.</param>
		/// <param name="appid">Identificador de la instacia de la aplicacion</param>
		/// <returns>Devuelve true si no ha ocurrido ningun error.</returns>
		public bool logout(string username, int appid){

		MySqlCommand MyCmd;

		try{
		
		if( this.conectar() )
		{
			username.Replace("\'","");
		MyCmd = new MySqlCommand("DELETE FROM logusers WHERE username = '" + username + "' AND instance = '" + appid + "'",conexion);

			MyCmd.ExecuteNonQuery();
			this.desconectar();
			return true;
		}else{
		return false;
		}

		}catch(MySqlException e){
			FM_Errores.MostrarError("logout","Error relacionado con la base de datos",e);
			return false;
		}catch(Exception err){
			FM_Errores.MostrarError("logout","Error haciendo logout",err);
			return false;
		}

		}
		
		/// <summary>
		/// Borra el usuario solicitado
		/// </summary>
		/// <param name="username">Nombre de usuario</param>
		/// <returns>Devuelve verdadero si ha tenido exito</returns>
		public bool DeleteUser(string username){

		MySqlCommand MyCmd;

		try{
		
		if( this.conectar() )
		{
			username.Replace("\'","");
		MyCmd = new MySqlCommand("DELETE FROM personal WHERE usuario = '" + username  + "'",conexion);

			MyCmd.ExecuteNonQuery();
			this.desconectar();
			return true;
		}else{
		return false;
		}

		}catch(MySqlException e){
			FM_Errores.MostrarError("DeleteUser","Error relacionado con la base de datos",e);
			return false;
		}catch(Exception err){
			FM_Errores.MostrarError("Deleteuser","Error borrando el usuario",err);
			return false;
		}

		}

		/// <summary>
		/// Obtiene la informacion de usuario y nivel de la instancia actual
		/// </summary>
		/// <returns>Devuelve un array de strings con 2 elementos: el primero es el nombre del usuario actual, el segundo es el nivel de restriccion del usuario</returns>
		public string[] GetInstanceInfo(int instance){
		
			string[] InstanceInfo = new string[2];
		
			MySqlCommand MyCmd;
			MySqlDataReader MyLector;
		
			try{
		
				if( this.conectar() )
				{
					MyCmd = new MySqlCommand("SELECT * FROM logusers WHERE instance = '" + instance +"'",conexion);
					MyLector = MyCmd.ExecuteReader();
				while( MyLector.Read() )
				{
					InstanceInfo[0] = MyLector.GetString(1); // Nombre del usuario
					InstanceInfo[1] = MyLector.GetString(3); // Nivel de autorizacion
				}
					this.desconectar();
					return InstanceInfo;
				}else{
					return InstanceInfo;
				}
			}catch(MySqlException e){
				FM_Errores.MostrarError("GetUserLoginList","Error relacionado con la base de datos",e);
				return InstanceInfo;
			}catch(Exception err){
				FM_Errores.MostrarError("GetUserLoginList","Error obteniendo lista de usuario",err);
				return InstanceInfo;
			}

		}

		/// <summary>
		/// Devulve el tipo de usuario asociado a un nivel
		/// </summary>
		/// <param name="level">Nivel asociado</param>
		/// <returns>Devuelve cadena con el tipo asociado</returns>
		public string GetTypeUser(int level){
		
			string tipouser = null;
			MySqlCommand MyCmd;
			MySqlDataReader MyLector;
			try{
				if( this.conectar() )
				{
					MyCmd = new MySqlCommand("SELECT * FROM tipopersonal WHERE Nivel = " + level.ToString(),conexion);
					MyLector = MyCmd.ExecuteReader();
		
				while( MyLector.Read() )
					tipouser = MyLector.GetString(1);
				
					this.desconectar();
					return (string) tipouser;
				}else{
					return tipouser;
				}
			}catch(MySqlException e){
				FM_Errores.MostrarError("GetTypeUser","Error relacionado con la base de datos",e);
				return tipouser;
			}catch(Exception err){
				FM_Errores.MostrarError("GetTypeUser","Error obteniendo lista de usuario",err);
				return tipouser;
			}
	
		}
		
		/// <summary>
		/// Obtiene la lista de los posibles tipos de usuarios
		/// </summary>
		/// <returns>Devuelve un array de strings con los tipos</returns>
		public string[] GetTipoUserList(){
		ArrayList usernames = new ArrayList();
		MySqlCommand MyCmd;
		MySqlDataReader MyLector;
		try{
		if( this.conectar() )
		{
		MyCmd = new MySqlCommand("SELECT * FROM tipopersonal",conexion);
		MyLector = MyCmd.ExecuteReader();
		
		while( MyLector.Read() )
			usernames.Add(MyLector.GetString(1));
		this.desconectar();
		return (string[])usernames.ToArray(typeof(string));
		}else{
		return (string[])usernames.ToArray(typeof(string));
		}
		}catch(MySqlException e){
			FM_Errores.MostrarError("GetTipoUserList","Error relacionado con la base de datos",e);
			return (string[])usernames.ToArray(typeof(string));
		}catch(Exception err){
			FM_Errores.MostrarError("GetTipoUserList","Error obteniendo lista de usuario",err);
			return (string[])usernames.ToArray(typeof(string));
		}
	
		}
		
		
		
		
		/// <summary>
		/// Obtiene los nombre de los usuario actualmente autentificados en el sistema.
		/// </summary>
		/// <returns>Devuelve una array de strings con los nombres de los usuarios.</returns>
		public string[] GetUserLoginList(){
		ArrayList usernames = new ArrayList();
		MySqlCommand MyCmd;
		MySqlDataReader MyLector;
		try{
		if( this.conectar() )
		{
		MyCmd = new MySqlCommand("SELECT * FROM logusers",conexion);
		MyLector = MyCmd.ExecuteReader();
		
		while( MyLector.Read() )
			usernames.Add(MyLector.GetString(0));
		this.desconectar();
		return (string[])usernames.ToArray(typeof(string));
		}else{
		return (string[])usernames.ToArray(typeof(string));
		}
		}catch(MySqlException e){
			FM_Errores.MostrarError("GetUserLoginList","Error relacionado con la base de datos",e);
			return (string[])usernames.ToArray(typeof(string));
		}catch(Exception err){
			FM_Errores.MostrarError("GetUserLoginList","Error obteniendo lista de usuario",err);
			return (string[])usernames.ToArray(typeof(string));
		}
	
		}
		/// <summary>
		/// Obtiene una lista de los usuarios posibles en el sistema
		/// </summary>
		/// <returns>Devuelve la lista en string[]</returns>
		public string[] GetUsersList(){
		ArrayList usernames = new ArrayList();
		MySqlCommand MyCmd;
		MySqlDataReader MyLector;
		try{
		if( this.conectar() )
		{
		MyCmd = new MySqlCommand("SELECT * FROM personal",conexion);
		MyLector = MyCmd.ExecuteReader();
		
		while( MyLector.Read() )
			usernames.Add(MyLector.GetString(4));
		this.desconectar();
		return (string[])usernames.ToArray(typeof(string));
		}else{
		return (string[])usernames.ToArray(typeof(string));
		}
		}catch(MySqlException e){
			FM_Errores.MostrarError("GetUsersList","Error relacionado con la base de datos",e);
			return (string[])usernames.ToArray(typeof(string));
		}catch(Exception err){
			FM_Errores.MostrarError("GetUsersList","Error obteniendo lista de usuarios",err);
			return (string[])usernames.ToArray(typeof(string));
		}

		}
#endregion	

	}
}
