/*
 *
 *	(C) 2006. Alvaro Cortes. alvarocortesc@gmail.com
 *
 *
 *	Modulo de gestion de impresion.
 *
 *
 */

using System;
using System.Drawing;
using System.Drawing.Printing;
using System.Drawing.Imaging;
using System.Windows.Forms;
using System.Collections;

namespace Formulacion{
	
	/// <summary>
	/// Clase heredera de PrinDocument para facilitar la impresion
	/// </summary>
	public class Impresiones : PrintDocument {

		/// <summary>
		/// Array original de los elementos a imprimir
		/// </summary>
		public ArrayList elementos = new ArrayList();
		
		/// <summary>
		/// Array de trabajo de los elementos a imprimir
		/// </summary>
		public ArrayList elementos_trabajo;
		
		float yPos;
		float MargenL, MargenR;
		
		/// <summary>
		/// Graphics donde se debe imprimir
		/// </summary>
		public Graphics gr; 
		/// <summary>
		/// Fuente por defecto para todo el documento
		/// </summary>
		public Font fuente;
		/// <summary>
		/// Pincel por defecto para todo el documento
		/// </summary>
		public Brush brocha;
		
		/// <summary>
		/// Inicializa la impresion con Arial,10 y Brocha negra en 0,10
		/// </summary>
		public Impresiones(){
			fuente = new Font("Arial",10);
			brocha = Brushes.Black;
			yPos = 0;
			MargenL = MargenR = 0;
			
		}
		
		
		/// <summary>
		/// Aade una nueva linea de texto al documento
		/// </summary>
		/// <param name="texto"></param>
		public void NuevoTexto(string texto){
			TextoImpresion ntexto = new TextoImpresion();
			ntexto.setTexto(texto);
			elementos.Add(ntexto);
		}
		
		/// <summary>
		/// Aade una linea horizontal al documento
		/// </summary>
		public void NuevaLinea(){
			LineaImpresion nlinea = new LineaImpresion();
			elementos.Add(nlinea);
			
		}
		
		/// <summary>
		/// Aade una imagen al documento
		/// </summary>
		/// <param name="path">Ubicacion de la imagen</param>
		public void NuevaImagen(string path){
			ImagenImpresion nimagen = new ImagenImpresion();
				if( nimagen.setImagen(path))
					elementos.Add(nimagen);
		}
				
		/// <summary>
		/// Imprime todos los elementos cargados en el documento
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		public void ImprimirElementos(object sender, PrintPageEventArgs e){
			
			this.gr = e.Graphics;
			yPos = 10;

			
			//foreach (Imprimible imprimibles in elementos)
			for(int i = 0; i < elementos_trabajo.Count; ++i)
			{
			
				Imprimible imprimibles = (Imprimible) elementos_trabajo[i];
				
				if( (float) (yPos + (float) imprimibles.GetAltura(gr)) >= e.PageBounds.Height )
				{
					elementos_trabajo.RemoveRange(0,i-1);
					e.HasMorePages = true;
					return;
				}
				if( this.MargenL == 0)
						imprimibles.setMargenL(e.PageBounds.Left+10);
				if( this.MargenR == 0)
					imprimibles.setMargenR(e.PageBounds.Right-5);
				
					imprimibles.Imprimete(gr,yPos);
					yPos = (float) (yPos + (float) imprimibles.GetAltura(gr));
					
				
					
			}
			
		}
		
		
		public void Reajustar(object sender, PrintEventArgs e)
		{
			elementos_trabajo = (ArrayList) this.elementos.Clone();
//			this.elementos_trabajo = this.elementos;
		}
		
		/// <summary>
		/// Aade una cabezera al documento
		/// </summary>
 		public void ImprimirCabezera(){

			Formulacion.PreferenciasServicio SrvPrefs;
			SrvPrefs = new Formulacion.PreferenciasServicio();
			SrvPrefs.AsignarNmbFichero("PrefServicio.xml");
			
			string[] prf = new string[5];
			
			// Carga de la configuracion del servicio
			if ( SrvPrefs.LeerFichero() )
			{
				prf = SrvPrefs.CargarPreferenciasServicio();
				SrvPrefs.CerrarEntrada();
				// prf queda tal que asi:
				//
				// 0 es Nombre del servicio
				// 1 es la Direccion
				// 2 es el Nombre del Licenciado
				// 3 es el tipo de Servicio
				// 4 son comentarios
			}

			
			NuevaImagen("img/banner.gif");
			NuevoTexto(prf[0]);
			NuevoTexto(prf[1].Replace('\n','.'));
			NuevoTexto("Licenciado " + prf[2]);
			NuevoTexto(prf[4]);
			NuevaLinea();
 		}
		
		
		
		/// <summary>
		/// 
		/// </summary>
		/// <param name="g"></param>
		public void ImprimirLinea(Graphics g){
			
		Pen pen = new Pen(brocha,1);
		
		try{
		g.DrawLine(pen, MargenL, yPos +2,MargenR, yPos+2);
		}catch(Exception e){
			FM_Errores.MostrarError("Impresion","No se puede imprimir la linea",e);
		}
			
		}
		
		/// <summary>
		/// Muestra un dialogo con las preferencias del documento.
		/// </summary>
	public void MuestraPrefsPagina()
    {
      PageSetupDialog PrefsPag = new PageSetupDialog();
      PageSettings settings = this.DefaultPageSettings;
      PrefsPag.PageSettings = settings;

      
      if(PrefsPag.ShowDialog() == DialogResult.OK)
        DefaultPageSettings = PrefsPag.PageSettings;
    	}

		
		
	}

	
	#region Tipos imprimibles 
	
	/// <summary>
	/// Define un elemento imprimible
	/// </summary>
	public interface Imprimible{
		
		/// <summary>
		/// Imprime realmente el elemento en el Graphics suministrado
		/// </summary>
		/// <param name="g">Grpahics donde imprimir</param>
		/// <param name="yPos">Posicion del vertical donde comenzar</param>
		void Imprimete(Graphics g, float yPos);

		/// <summary>
		/// Devuelve la altura del elemento para el calculo de yPos
		/// </summary>
		/// <param name="g">Graphics donde se impimira el elemento</param>
		float GetAltura(Graphics g);

		/// <summary>
		/// Establece el margen derecho
		/// </summary>
		/// <param name="margen">Float con el margen</param>
		void setMargenR(float margen);
		/// <summary>
		/// Establece el margen izquierdo
		/// </summary>
		/// <param name="margen">Float con el margen</param>
		void setMargenL(float margen);
			
	}
	
	/// <summary>
	/// Objeto imprimible de tipo texto
	/// </summary>
	public class TextoImpresion : Imprimible{
		
		/// <summary>
		/// Texto a imprimir
		/// </summary>
		public string texto;
		/// <summary>
		/// Fuente a utilizar
		/// </summary>
		public Font fuente;
		/// <summary>
		/// Brocha a utilizar
		/// </summary>
		public Brush brocha;
		/// <summary>
		/// Margen derecho
		/// </summary>
		public float MargenR;
		/// <summary>
		/// Margen izquierdo
		/// </summary>
		public float MargenL;
		
		/// <summary>
		/// Constructor de la clase
		/// </summary>
		public TextoImpresion(){
			fuente = new Font("Arial",10);
			brocha = Brushes.Black;
			MargenL = 10;
			MargenR = 10;
		}
		
		/// <summary>
		/// Establece el margen derecho para la linea
		/// </summary>
		/// <param name="margen">Margen a establecer</param>
		public void setMargenR(float margen){
			MargenR = margen;
		}
		
		/// <summary>
		/// Establece el margen izquierdo para la linea
		/// </summary>
		/// <param name="margen">Margen a establecer</param>
		public void setMargenL(float margen){
			MargenL = margen;
		}
		
		
		/// <summary>
		/// Establece el texto a imprimir
		/// </summary>
		/// <param name="text"></param>
		public void setTexto(string text){
			texto = text;
		}
		
		/// <summary>
		/// Devuelve la altura del elemento en el documento
		/// </summary>
		/// <param name="g"></param>
		/// <returns></returns>
		public float GetAltura(Graphics g){
			return fuente.GetHeight(g);
			
		}
		
		/// <summary>
		/// Imprime la linea en el documento
		/// </summary>
		/// <param name="g">Graphics a utilizar</param>
		/// <param name="yPos">Posicion de inicio</param>
		public void Imprimete(Graphics g, float yPos){
			g.DrawString(texto, fuente, brocha,MargenL,yPos);
		}
		
	}
	
	
	
	/// <summary>
	/// Objeto imprimible de tipo linea horizontal
	/// </summary>
	public class LineaImpresion : Imprimible{
		
		/// <summary>
		/// Brocha a utilizar
		/// </summary>
		public Brush brocha;
		/// <summary>
		/// Margen derecho
		/// </summary>
		public float MargenR;
		/// <summary>
		/// Margen Izquierdo
		/// </summary>
		public float MargenL;
		
		/// <summary>
		/// Contructor de la clase
		/// </summary>
		public LineaImpresion(){
			brocha = Brushes.Black;
		}
		
		/// <summary>
		/// Establece el margen derecho de la linea
		/// </summary>
		/// <param name="margen">Margen a establecer</param>
		public void setMargenR(float margen){
			MargenR = margen;
		}
		
		/// <summary>
		/// Establece el margen izquierdo de la linea
		/// </summary>
		/// <param name="margen">Margen a establecer</param>
		public void setMargenL(float margen){
			MargenL = margen;
		}
		
		/// <summary>
		/// Devuelve la altura del elemento en el documento
		/// </summary>
		/// <param name="g"></param>
		/// <returns></returns>
		public float GetAltura(Graphics g){
			return 10;
		}

		/// <summary>
		/// Imprime la linea en el documento
		/// </summary>
		/// <param name="g">Graphics a utilizar</param>
		/// <param name="yPos">Posicion de inicio</param>
		public void Imprimete(Graphics g, float yPos){
			Pen pen = new Pen(brocha,1);
			g.DrawLine(pen, MargenL, yPos +5,MargenR, yPos+5);
		}
		
	}
	
	/// <summary>
	/// Objeto imprimible de tipo imagen
	/// </summary>
		public class ImagenImpresion : Imprimible{
		
		/// <summary>
		/// Ruta de la imagen
		/// </summary>
		public string path;
		/// <summary>
		/// Fuente a utilizar
		/// </summary>
		public Font fuente;
		/// <summary>
		/// Brocha a utilizar
		/// </summary>
		public Brush brocha;
		/// <summary>
		/// Margen derecho
		/// </summary>
		public float MargenR;
		/// <summary>
		/// Margen izquierdo
		/// </summary>
		public float MargenL;
		/// <summary>
		/// Imagen a imprimir
		/// </summary>
		public Image imagen;
		
		/// <summary>
		/// Constructor de la clase
		/// </summary>
		public ImagenImpresion(){
			fuente = new Font("Arial",10);
			brocha = Brushes.Black;
			MargenL = 10;
			MargenR = 10;
		}
		
		/// <summary>
		/// Asigna el margen derecho a la linea
		/// </summary>
		/// <param name="margen">Margen a establecer</param>
		public void setMargenR(float margen){
			MargenR = margen;
		}
		
		/// <summary>
		/// Asigna el margen izquierdo a la linea
		/// </summary>
		/// <param name="margen">Margen a establecer</param>
		public void setMargenL(float margen){
			MargenL = margen;
		}
		
		/// <summary>
		/// Establece la imagen
		/// </summary>
		/// <param name="text">Ruta de la imagen</param>
		/// <returns>Devuelve verdadero si ha tenido xito cargando la imagen</returns>
		public bool setImagen(string text){
			path=text;
			try{
			imagen = Image.FromFile(text);
			return true;
			}catch(Exception e){
				FM_Errores.MostrarError("Impresion","No se puede imprimir la imagen ubicada en " + text,e);
				return false;
			}
		}

		
		/// <summary>
		/// Devuelve la altura del elemento en el documento
		/// </summary>
		/// <param name="g"></param>
		/// <returns></returns>
		public float GetAltura(Graphics g){
			return imagen.Height;
		}

		/// <summary>
		/// Imprime la imagen en el documento
		/// </summary>
		/// <param name="g">Graphics a utilizar</param>
		/// <param name="yPos">Posicion de inicio</param>
		public void Imprimete(Graphics g, float yPos){
			//g.DrawImage(imagen,new System.Drawing.PointF(yPos,MargenL));
			g.DrawImage(imagen,new System.Drawing.PointF(MargenL,yPos));
		}
		
	}

	

	#endregion
	
	
}
