/*
 * 
 * Materia_rutinas.cs
 * 
 * (C) Alvaro Cortes. 2007. alvarocortesc@gmail.com
 * 
 * 
 * 
 * Algunas cosas para usar en MainForm.
 * 
 */

using System;
using System.Data;
using MySql.Data.MySqlClient;
using System.Collections;

namespace FormulacionMagistral
{
	/// <summary>
	/// Description of Materia_rutinas.
	/// </summary>
	public class Materia_rutinas
	{
		/// <summary>
		/// Obtiene una lista de todas las materias primas
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <returns>string[] con los nombres de las materias primas</returns>
		public static string[] get_list_materias(string strconn){
		
		ArrayList materias = new ArrayList();
		MySqlCommand MyCmd;
		MySqlConnection conexion;
		MySqlDataReader MyLector;
		
		try{
			conexion = new MySqlConnection(strconn);
			conexion.Open();
		
				MyCmd = new MySqlCommand("SELECT * FROM materia ORDER BY MateriaID",conexion);
				MyLector = MyCmd.ExecuteReader();
			while( MyLector.Read() )
				materias.Add(MyLector.GetString(1));
		MyLector.Close();
		conexion.Close();
		return (string[])materias.ToArray(typeof(string));
		}catch(MySqlException e){
			FM_Errores.MostrarError("get_list_materias","Error relacionado con la base de datos",e);
			return (string[])materias.ToArray(typeof(string));
		}catch(Exception err){
			FM_Errores.MostrarError("get_list_materias","Error obteniendo lista de materias primas",err);
			return (string[])materias.ToArray(typeof(string));
		}
			
		}

		/// <summary>
		/// Obtiene una lista de los sinonimos de la materia prima
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <param name="materiaid">ID de la materia</param>
		/// <returns>string[] con los nombres de las materias primas</returns>
		public static string[] get_sinonimos(string strconn, string materiaid){
		
		ArrayList materias = new ArrayList();
		MySqlCommand MyCmd;
		MySqlConnection conexion;
		MySqlDataReader MyLector;
		
		try{
			conexion = new MySqlConnection(strconn);
			conexion.Open();
		
				MyCmd = new MySqlCommand("SELECT * FROM sinonimos WHERE MateriaID = "+ materiaid + ";",conexion);
				MyLector = MyCmd.ExecuteReader();
			while( MyLector.Read() )
				materias.Add(MyLector.GetString(1));
		MyLector.Close();
		conexion.Close();
		return (string[])materias.ToArray(typeof(string));
		}catch(MySqlException e){
			FM_Errores.MostrarError("get_sinonimos","Error relacionado con la base de datos",e);
			return (string[])materias.ToArray(typeof(string));
		}catch(Exception err){
			FM_Errores.MostrarError("get_sinonimos","Error obteniendo lista de sinonimos",err);
			return (string[])materias.ToArray(typeof(string));
		}
			
		}
		
		/// <summary>
		/// Devuelve el id asociado al nombre de la materia
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <param name="nombre">Nombre de la materia</param>
		/// <returns>string[] con los nombres de las materias primas</returns>
		public static string get_materiaid(string strconn, string nombre){
		
		MySqlCommand MyCmd;
		MySqlConnection conexion;
		MySqlDataReader MyLector;
		int materiaid = -1;
		
		try{
			conexion = new MySqlConnection(strconn);
			conexion.Open();
		
				MyCmd = new MySqlCommand("SELECT * FROM materia WHERE DOE = '"+ nombre + "';",conexion);
				MyLector = MyCmd.ExecuteReader();
			while( MyLector.Read() )
				materiaid = MyLector.GetInt32(0);
		MyLector.Close();
		conexion.Close();
		return materiaid.ToString();
		}catch(MySqlException e){
			FM_Errores.MostrarError("get_materiaid","Error relacionado con la base de datos",e);
		return materiaid.ToString();
		}catch(Exception err){
			FM_Errores.MostrarError("get_materiaid","Error obteniendo el identificador de la materia",err);
			return materiaid.ToString();
		}
			
		}
				

		/// <summary>
		/// Obtiene toda la informacion de la tabla especificaciones
		/// </summary>
		/// <param name="strconn">Cadena de conexion</param>
		/// <param name="materiaid">ID de la materia</param>
		/// <returns>string[] con los campos de la tabla</returns>
		public static string[] get_especificaciones(string strconn, string materiaid){
		
		ArrayList materias = new ArrayList();
		MySqlCommand MyCmd;
		MySqlConnection conexion;
		MySqlDataReader MyLector;
		
		try{
			conexion = new MySqlConnection(strconn);
			conexion.Open();
		
				MyCmd = new MySqlCommand("SELECT * FROM especificaciones WHERE MateriaID = "+ materiaid + ";",conexion);
				MyLector = MyCmd.ExecuteReader();
				if( MyLector.Read() )
				{
					materias.Add( MyLector.GetInt32(1).ToString() ); // UnidadID
					for(int i=2; i<= 9 ; ++i)
					materias.Add(MyLector.GetString(i)); // Campos de texto
					materias.Add(MyLector.GetFloat(10).ToString()); // Precio
				}
		MyLector.Close();
		conexion.Close();
		return (string[])materias.ToArray(typeof(string));
		}catch(MySqlException e){
			FM_Errores.MostrarError("get_especificaciones","Error relacionado con la base de datos",e);
			return (string[])materias.ToArray(typeof(string));
		}catch(Exception err){
			FM_Errores.MostrarError("get_especificaciones","Error obteniendo especificaciones",err);
			return (string[])materias.ToArray(typeof(string));
		}
			
		}
		
		
		
	}
}
