/*
 * 
 * Personal Mini Vista
 * 
 * 
 * (C) Alvaro Cortes. alvarocortesc@gmail.com
 * 
 * 
 * Proporciona una vista en general del personal.
 * 
 */

using System;
using System.Drawing;
using System.Windows.Forms;

using System.Drawing.Printing;
using MySql.Data.MySqlClient;
using System.Data;


namespace FormulacionMagistral
{
	/// <summary>
	/// Description of PersonalMiniVista.
	/// </summary>
	public class PersonalMiniVista : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Button btnGuardar;
		private System.Windows.Forms.TextBox txtUser;
		private System.Windows.Forms.Button btnImprimir;
		private System.Windows.Forms.Button btnNuevo;
		private System.Windows.Forms.Label lblApellidos;
		private System.Windows.Forms.ComboBox cmbTipoUsuario;
		private System.Windows.Forms.Label lblPos;
		private System.Windows.Forms.Label lblTipoUser;
		private System.Windows.Forms.Button btnCerrar;
		private System.Windows.Forms.Button btnFirst;
		private System.Windows.Forms.Button btnPrev;
		private System.Windows.Forms.Label lblPassword;
		private System.Windows.Forms.TextBox txtApellidos;
		private System.Windows.Forms.Label lblNombre;
		private System.Windows.Forms.TextBox txtPersonalID;
		private System.Windows.Forms.PictureBox pctAvatar;
		private System.Windows.Forms.TextBox txtPassword;
		private System.Windows.Forms.TextBox txtNombre;
		private System.Windows.Forms.Button btnCambiar;
		private System.Windows.Forms.Label lblUser;
		private System.Windows.Forms.Button btnNext;
		private System.Windows.Forms.Button btnLast;
		private System.Windows.Forms.Button btnSelect;
		private System.Windows.Forms.Button btnImprimirListado;
		private System.Windows.Forms.Label lblPersonalID;
		
		
		private Formulacion.FarmaAuthorize SecLocal;
		private Alertas AlertaLocal; // Alertas

		
		private int currentlevel;   // Nivel de autorizacion del usuario actual
		
		#region Objetos de la base de datos (Adapters, Connection, DataSets)
		private MySqlParameter parm;
		
		private MySqlDataAdapter adap;  // adapter general
		private DataSet ds;               // ds general
		private MySqlConnection conn;      // conexion 

		#endregion
		
		// Para cargar preferencias de la BD
		private Formulacion.PreferenciasDB DBPrefs;
		
		// Informacion para conexion BD
		private string dbhost;
		private string dbport;
		private string dbuser;
		private string dbpasoteword;

		// Algunas variables para emular el CurrencyManager defectuoso de Mono
		private int RecCount;
		
		/// <summary>
		/// Indica el registro actual visionado en el form
		/// </summary>
		public int RecPosition;


		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="level">Nivel de acceso</param>
		/// <param name="registro">ID de personal a cargar. Menor de 0 carga todos</param>
		public PersonalMiniVista(int level, int registro)
		{
			//
			// The InitializeComponent() call is required for Windows Forms designer support.
			//
			InitializeComponent();
			
			this.currentlevel = level;
			
			DBPrefs = new Formulacion.PreferenciasDB();
			DBPrefs.AsignarNmbFichero("PrefDataBase.xml");
			
			this.RecPosition = registro;
			AlertaLocal = new Alertas();
			SecLocal = new Formulacion.FarmaAuthorize();
		}
		
		/// <summary>
		/// Obtiene el id del registro actual
		/// </summary>
		/// <returns>Devuelve un entero del ID del registro</returns>
		public int getcurrentid(){
			int n;
			try{
				n = Convert.ToInt32( this.txtPersonalID.Text);
				return n;
			}catch(Exception ex){
				FM_Errores.MostrarError("GetCurrentID","No se puede obtener el ID actual",ex);
				return -1;
			}
		}

		
		
		/// <summary>
		/// Carga la configuracin de la base de datos en la vars
		/// de la clase
		/// </summary>
		void CargarConfiguracionDatabase(){
			string[] prf;
			if ( this.DBPrefs.LeerFichero() )
			{
				prf = this.DBPrefs.CargarPreferenciasDB();
				
				for( int i = 0; i < prf.Length; ++i)
				{
					switch(i){
						case 0: this.dbhost = prf[0]; break;
						case 1: this.dbport = prf[1]; break;
						case 3: this.dbuser = prf[2]; break;
						case 4: this.dbpasoteword = prf[3]; break;
					
					}
				}
				this.DBPrefs.CerrarEntrada();
			}
		}

		private bool Conectar(int registro){
			try{
		 	conn = new MySqlConnection("host="+this.dbhost+";port=" + this.dbport + ";user id="+this.dbuser+";password="+this.dbpasoteword+ ";database=formulacion");

		 	adap = new MySqlDataAdapter();
			ds = new System.Data.DataSet();
			
			if( registro >= 0){
		 		adap.SelectCommand = new MySqlCommand("SELECT * FROM personal WHERE PersonalID="+ registro.ToString() + ";",conn);
		 		
			}
		 	else{
			 	adap.SelectCommand = new MySqlCommand("SELECT * FROM personal;",conn);
				}
			adap.Fill(ds,"Personal");
		 	
		 	return true;
			}catch(MySqlException ex){
				FM_Errores.MostrarError("PersonalMiniVista","Error relacionado con base de datos",ex);
				return false;
			}catch(Exception e){
				FM_Errores.MostrarError("PersonalMiniVista","Error general. No se puede cargar la informacion del personal",e);
				return false;
			}
		 	
		}

		private void CargarComandoUpdate(){
			adap.UpdateCommand = new MySqlCommand("Update personal Set Nombre = ?Nombre, Apellidos = ?Apellidos, Usuario=?Usuario, Pasoteword = ?Pasoteword, Avatar=?Avatar, TipoID = ?TipoID WHERE PersonalID = ?PersonalID",conn);
			//adap.UpdateCommand = new MySqlCommand("Update personal Set PersonalID = ?PersonalID, Nombre = ?Nombre, Apellidos = ?Apellidos, Usuario=?Usuario, Pasoteword = ?Pasoteword, Avatar=?Avatar, TipoID = ?TipoID",conn);
			parm = adap.UpdateCommand.Parameters.Add("?PersonalID", MySqlDbType.Int32);
			parm.SourceColumn = "PersonalID";
			parm.SourceVersion = DataRowVersion.Original;
							
			parm = adap.UpdateCommand.Parameters.Add("?Nombre", MySqlDbType.VarChar, 50 );
			parm.SourceColumn = "Nombre";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.UpdateCommand.Parameters.Add("?Apellidos", MySqlDbType.VarChar, 100 );
			parm.SourceColumn = "Apellidos";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.UpdateCommand.Parameters.Add("?Usuario", MySqlDbType.VarChar, 20 );
			parm.SourceColumn = "Usuario";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.UpdateCommand.Parameters.Add("?Pasoteword", MySqlDbType.VarChar, 50 );
			parm.SourceColumn = "Pasoteword";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.UpdateCommand.Parameters.Add("?Avatar", MySqlDbType.VarChar, 300 );
			parm.SourceColumn = "Avatar";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.UpdateCommand.Parameters.Add("?TipoID", MySqlDbType.Int32 );
			parm.SourceColumn = "TipoID";
			parm.SourceVersion = DataRowVersion.Current;

		}
		
		private void CargarComandoDelete(){
			adap.DeleteCommand = new MySqlCommand("DELETE FROM personal WHERE PersonalID = ?PersonalID",conn);
			
			parm = adap.DeleteCommand.Parameters.Add("?PersonalID", MySqlDbType.Int32);
			parm.SourceColumn = "PersonalID";
			parm.SourceVersion = DataRowVersion.Original;
			
		}
		
		private void CargarComandoInsert(){
			adap.InsertCommand = new MySqlCommand("Insert into personal(PersonalID, Nombre, Apellidos, Usuario, Pasoteword, Avatar, TipoID) VALUES (?PersonalID, ?Nombre, ?Apellidos, ?Usuario,?Pasoteword,?Avatar,?TipoID)",conn);
			
			parm = adap.InsertCommand.Parameters.Add("?PersonalID", MySqlDbType.Int32);
			parm.SourceColumn = "PersonalID";
			parm.SourceVersion = DataRowVersion.Original;
							
			parm = adap.InsertCommand.Parameters.Add("?Nombre", MySqlDbType.VarChar, 50 );
			parm.SourceColumn = "Nombre";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?Apellidos", MySqlDbType.VarChar, 100 );
			parm.SourceColumn = "Apellidos";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.InsertCommand.Parameters.Add("?Usuario", MySqlDbType.VarChar, 20 );
			parm.SourceColumn = "Usuario";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?Pasoteword", MySqlDbType.VarChar, 50 );
			parm.SourceColumn = "Pasoteword";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.InsertCommand.Parameters.Add("?Avatar", MySqlDbType.VarChar, 300 );
			parm.SourceColumn = "Avatar";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?TipoID", MySqlDbType.Int32 );
			parm.SourceColumn = "TipoID";
			parm.SourceVersion = DataRowVersion.Current;

		}

		
		#region Windows Forms Designer generated code
		/// <summary>
		/// This method is required for Windows Forms designer support.
		/// Do not change the method contents inside the source code editor. The Forms designer might
		/// not be able to load this method if it was changed manually.
		/// </summary>
		private void InitializeComponent() {
			this.lblPersonalID = new System.Windows.Forms.Label();
			this.btnImprimirListado = new System.Windows.Forms.Button();
			this.btnSelect = new System.Windows.Forms.Button();
			this.btnLast = new System.Windows.Forms.Button();
			this.btnNext = new System.Windows.Forms.Button();
			this.lblUser = new System.Windows.Forms.Label();
			this.btnCambiar = new System.Windows.Forms.Button();
			this.txtNombre = new System.Windows.Forms.TextBox();
			this.txtPassword = new System.Windows.Forms.TextBox();
			this.pctAvatar = new System.Windows.Forms.PictureBox();
			this.txtPersonalID = new System.Windows.Forms.TextBox();
			this.lblNombre = new System.Windows.Forms.Label();
			this.txtApellidos = new System.Windows.Forms.TextBox();
			this.lblPassword = new System.Windows.Forms.Label();
			this.btnPrev = new System.Windows.Forms.Button();
			this.btnFirst = new System.Windows.Forms.Button();
			this.btnCerrar = new System.Windows.Forms.Button();
			this.lblTipoUser = new System.Windows.Forms.Label();
			this.lblPos = new System.Windows.Forms.Label();
			this.cmbTipoUsuario = new System.Windows.Forms.ComboBox();
			this.lblApellidos = new System.Windows.Forms.Label();
			this.btnNuevo = new System.Windows.Forms.Button();
			this.btnImprimir = new System.Windows.Forms.Button();
			this.txtUser = new System.Windows.Forms.TextBox();
			this.btnGuardar = new System.Windows.Forms.Button();
			this.SuspendLayout();
			// 
			// lblPersonalID
			// 
			this.lblPersonalID.Location = new System.Drawing.Point(24, 16);
			this.lblPersonalID.Name = "lblPersonalID";
			this.lblPersonalID.Size = new System.Drawing.Size(72, 16);
			this.lblPersonalID.TabIndex = 4;
			this.lblPersonalID.Text = "PersonalID";
			// 
			// btnImprimirListado
			// 
			this.btnImprimirListado.Location = new System.Drawing.Point(456, 120);
			this.btnImprimirListado.Name = "btnImprimirListado";
			this.btnImprimirListado.Size = new System.Drawing.Size(104, 24);
			this.btnImprimirListado.TabIndex = 44;
			this.btnImprimirListado.Text = "Imprimir Listado";
			this.btnImprimirListado.Click += new System.EventHandler(this.BtnImprimirListadoClick);
			// 
			// btnSelect
			// 
			this.btnSelect.Location = new System.Drawing.Point(280, 120);
			this.btnSelect.Name = "btnSelect";
			this.btnSelect.Size = new System.Drawing.Size(152, 24);
			this.btnSelect.TabIndex = 45;
			this.btnSelect.Text = "Seleccionar Imagen";
			this.btnSelect.Click += new System.EventHandler(this.BtnSelectClick);
			// 
			// btnLast
			// 
			this.btnLast.Location = new System.Drawing.Point(520, 192);
			this.btnLast.Name = "btnLast";
			this.btnLast.Size = new System.Drawing.Size(32, 24);
			this.btnLast.TabIndex = 37;
			this.btnLast.Text = "->|";
			this.btnLast.Click += new System.EventHandler(this.BtnLastClick);
			// 
			// btnNext
			// 
			this.btnNext.Location = new System.Drawing.Point(488, 192);
			this.btnNext.Name = "btnNext";
			this.btnNext.Size = new System.Drawing.Size(32, 24);
			this.btnNext.TabIndex = 36;
			this.btnNext.Text = "->";
			this.btnNext.Click += new System.EventHandler(this.BtnNextClick);
			// 
			// lblUser
			// 
			this.lblUser.Location = new System.Drawing.Point(24, 144);
			this.lblUser.Name = "lblUser";
			this.lblUser.Size = new System.Drawing.Size(64, 16);
			this.lblUser.TabIndex = 3;
			this.lblUser.Text = "Usuario";
			// 
			// btnCambiar
			// 
			this.btnCambiar.Location = new System.Drawing.Point(280, 176);
			this.btnCambiar.Name = "btnCambiar";
			this.btnCambiar.Size = new System.Drawing.Size(80, 24);
			this.btnCambiar.TabIndex = 50;
			this.btnCambiar.Text = "Cambiar";
			this.btnCambiar.Click += new System.EventHandler(this.BtnCambiarClick);
			// 
			// txtNombre
			// 
			this.txtNombre.Location = new System.Drawing.Point(96, 48);
			this.txtNombre.Name = "txtNombre";
			this.txtNombre.Size = new System.Drawing.Size(168, 20);
			this.txtNombre.TabIndex = 0;
			this.txtNombre.Text = "";
			// 
			// txtPassword
			// 
			this.txtPassword.Enabled = false;
			this.txtPassword.Location = new System.Drawing.Point(104, 176);
			this.txtPassword.Name = "txtPassword";
			this.txtPassword.Size = new System.Drawing.Size(168, 20);
			this.txtPassword.TabIndex = 49;
			this.txtPassword.Text = "";
			// 
			// pctAvatar
			// 
			this.pctAvatar.Location = new System.Drawing.Point(288, 8);
			this.pctAvatar.Name = "pctAvatar";
			this.pctAvatar.Size = new System.Drawing.Size(144, 104);
			this.pctAvatar.SizeMode = System.Windows.Forms.PictureBoxSizeMode.StretchImage;
			this.pctAvatar.TabIndex = 8;
			this.pctAvatar.TabStop = false;
			// 
			// txtPersonalID
			// 
			this.txtPersonalID.Location = new System.Drawing.Point(96, 16);
			this.txtPersonalID.Name = "txtPersonalID";
			this.txtPersonalID.Size = new System.Drawing.Size(168, 20);
			this.txtPersonalID.TabIndex = 5;
			this.txtPersonalID.Text = "";
			// 
			// lblNombre
			// 
			this.lblNombre.Location = new System.Drawing.Point(24, 48);
			this.lblNombre.Name = "lblNombre";
			this.lblNombre.Size = new System.Drawing.Size(64, 24);
			this.lblNombre.TabIndex = 1;
			this.lblNombre.Text = "Nombre";
			// 
			// txtApellidos
			// 
			this.txtApellidos.Location = new System.Drawing.Point(96, 80);
			this.txtApellidos.Name = "txtApellidos";
			this.txtApellidos.Size = new System.Drawing.Size(168, 20);
			this.txtApellidos.TabIndex = 6;
			this.txtApellidos.Text = "";
			// 
			// lblPassword
			// 
			this.lblPassword.Location = new System.Drawing.Point(24, 176);
			this.lblPassword.Name = "lblPassword";
			this.lblPassword.Size = new System.Drawing.Size(72, 16);
			this.lblPassword.TabIndex = 47;
			this.lblPassword.Text = "Password";
			// 
			// btnPrev
			// 
			this.btnPrev.Location = new System.Drawing.Point(456, 192);
			this.btnPrev.Name = "btnPrev";
			this.btnPrev.Size = new System.Drawing.Size(32, 24);
			this.btnPrev.TabIndex = 35;
			this.btnPrev.Text = "<-";
			this.btnPrev.Click += new System.EventHandler(this.BtnPrevClick);
			// 
			// btnFirst
			// 
			this.btnFirst.Location = new System.Drawing.Point(424, 192);
			this.btnFirst.Name = "btnFirst";
			this.btnFirst.Size = new System.Drawing.Size(32, 24);
			this.btnFirst.TabIndex = 34;
			this.btnFirst.Text = "|<-";
			this.btnFirst.Click += new System.EventHandler(this.BtnFirstClick);
			// 
			// btnCerrar
			// 
			this.btnCerrar.Location = new System.Drawing.Point(456, 152);
			this.btnCerrar.Name = "btnCerrar";
			this.btnCerrar.Size = new System.Drawing.Size(104, 24);
			this.btnCerrar.TabIndex = 42;
			this.btnCerrar.Text = "Cerrar";
			this.btnCerrar.Click += new System.EventHandler(this.BtnCerrarClick);
			// 
			// lblTipoUser
			// 
			this.lblTipoUser.Location = new System.Drawing.Point(24, 216);
			this.lblTipoUser.Name = "lblTipoUser";
			this.lblTipoUser.Size = new System.Drawing.Size(80, 16);
			this.lblTipoUser.TabIndex = 46;
			this.lblTipoUser.Text = "Tipo Usuario";
			// 
			// lblPos
			// 
			this.lblPos.Location = new System.Drawing.Point(424, 216);
			this.lblPos.Name = "lblPos";
			this.lblPos.Size = new System.Drawing.Size(128, 24);
			this.lblPos.TabIndex = 38;
			this.lblPos.Text = "0 de 0";
			this.lblPos.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// cmbTipoUsuario
			// 
			this.cmbTipoUsuario.Location = new System.Drawing.Point(104, 216);
			this.cmbTipoUsuario.Name = "cmbTipoUsuario";
			this.cmbTipoUsuario.Size = new System.Drawing.Size(168, 21);
			this.cmbTipoUsuario.TabIndex = 48;
			// 
			// lblApellidos
			// 
			this.lblApellidos.Location = new System.Drawing.Point(24, 88);
			this.lblApellidos.Name = "lblApellidos";
			this.lblApellidos.Size = new System.Drawing.Size(64, 24);
			this.lblApellidos.TabIndex = 2;
			this.lblApellidos.Text = "Apellidos";
			// 
			// btnNuevo
			// 
			this.btnNuevo.Location = new System.Drawing.Point(456, 24);
			this.btnNuevo.Name = "btnNuevo";
			this.btnNuevo.Size = new System.Drawing.Size(104, 24);
			this.btnNuevo.TabIndex = 39;
			this.btnNuevo.Text = "Nuevo";
			this.btnNuevo.Click += new System.EventHandler(this.BtnNuevoClick);
			// 
			// btnImprimir
			// 
			this.btnImprimir.Location = new System.Drawing.Point(456, 88);
			this.btnImprimir.Name = "btnImprimir";
			this.btnImprimir.Size = new System.Drawing.Size(104, 24);
			this.btnImprimir.TabIndex = 43;
			this.btnImprimir.Text = "Imprimir Ficha";
			this.btnImprimir.Click += new System.EventHandler(this.BtnImprimirClick);
			// 
			// txtUser
			// 
			this.txtUser.Location = new System.Drawing.Point(104, 136);
			this.txtUser.Name = "txtUser";
			this.txtUser.Size = new System.Drawing.Size(168, 20);
			this.txtUser.TabIndex = 7;
			this.txtUser.Text = "";
			// 
			// btnGuardar
			// 
			this.btnGuardar.Location = new System.Drawing.Point(456, 56);
			this.btnGuardar.Name = "btnGuardar";
			this.btnGuardar.Size = new System.Drawing.Size(104, 24);
			this.btnGuardar.TabIndex = 40;
			this.btnGuardar.Text = "Guardar";
			this.btnGuardar.Click += new System.EventHandler(this.BtnGuardarClick);
			// 
			// PersonalMiniVista
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(568, 253);
			this.Controls.Add(this.btnCambiar);
			this.Controls.Add(this.txtPassword);
			this.Controls.Add(this.cmbTipoUsuario);
			this.Controls.Add(this.lblPassword);
			this.Controls.Add(this.lblTipoUser);
			this.Controls.Add(this.btnSelect);
			this.Controls.Add(this.btnImprimirListado);
			this.Controls.Add(this.btnImprimir);
			this.Controls.Add(this.btnCerrar);
			this.Controls.Add(this.btnGuardar);
			this.Controls.Add(this.btnNuevo);
			this.Controls.Add(this.lblPos);
			this.Controls.Add(this.btnLast);
			this.Controls.Add(this.btnNext);
			this.Controls.Add(this.btnPrev);
			this.Controls.Add(this.btnFirst);
			this.Controls.Add(this.pctAvatar);
			this.Controls.Add(this.txtUser);
			this.Controls.Add(this.txtApellidos);
			this.Controls.Add(this.txtPersonalID);
			this.Controls.Add(this.lblPersonalID);
			this.Controls.Add(this.lblUser);
			this.Controls.Add(this.lblApellidos);
			this.Controls.Add(this.lblNombre);
			this.Controls.Add(this.txtNombre);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "PersonalMiniVista";
			this.Text = "Vista de Personal";
			this.Load += new System.EventHandler(this.PersonalMiniVistaLoad);
			this.ResumeLayout(false);
		}
		#endregion
		void BtnImprimirClick(object sender, System.EventArgs e)
		{
		if (MessageBox.Show("Desea imprimir los avatares?", "Pregunta impresin", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
			this.ImprimirListado(this.RecPosition,this.RecPosition+1,false);
		else
			this.ImprimirListado(this.RecPosition,this.RecPosition+1,true);

			
		}
		
		/// <summary>
		/// Carga el combo de tipos de usuario con los existentes en la tabla
		/// de la base de datos
		/// </summary>
		void CargarTiposUsuarios(){
			string[] tiposusuarios;
			tiposusuarios = SecLocal.GetTipoUserList();
			for( int i= 0; i < tiposusuarios.Length; ++i)
				this.cmbTipoUsuario.Items.Add(tiposusuarios[i]);
		}

		
		
		void PersonalMiniVistaLoad(object sender, System.EventArgs e)
		{
			this.CargarConfiguracionDatabase();
			SecLocal.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");
			AlertaLocal.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");
			if ( this.Conectar(this.RecPosition) )
			{
				this.RecPosition = 0;
				this.CargarComandoUpdate();
				this.CargarComandoInsert();
				this.CargarComandoDelete();
				this.RecCount = ds.Tables[0].Rows.Count;
				CargarTiposUsuarios();
			    MostrarPosicion();
			    this.CargarRegistro(this.RecPosition);
			}

		}
		
		void MostrarPosicion(){
			this.lblPos.Text = (this.RecPosition+1).ToString() + " de " + this.RecCount.ToString();
		}

		void CargarRegistro( int numero){
			
			if( numero >=0 && numero < ds.Tables[0].Rows.Count)
			{
				this.txtPersonalID.Text = ds.Tables[0].Rows[numero]["PersonalID"].ToString();
				this.txtNombre.Text = ds.Tables[0].Rows[numero]["Nombre"].ToString();
				this.txtApellidos.Text = ds.Tables[0].Rows[numero]["Apellidos"].ToString();
				this.txtUser.Text = ds.Tables[0].Rows[numero]["Usuario"].ToString();
				this.txtPassword.Text = ds.Tables[0].Rows[numero]["Pasoteword"].ToString();
				
				if( System.IO.File.Exists( ds.Tables[0].Rows[numero]["Avatar"].ToString() ) )
				this.pctAvatar.Image = Image.FromFile(ds.Tables[0].Rows[numero]["Avatar"].ToString());
				if ( Convert.ToInt32 (ds.Tables[0].Rows[numero]["TipoID"]) >0)
				this.cmbTipoUsuario.Text = SecLocal.GetTypeUser ( Convert.ToInt32 (ds.Tables[0].Rows[numero]["TipoID"]) );
			}
		}

		
		void GuardarRegistro( int numero){
			try{
				ds.AcceptChanges();
			ds.Tables[0].Rows[numero].BeginEdit();
			ds.Tables[0].Rows[numero]["PersonalID"] = Convert.ToInt32 (this.txtPersonalID.Text);
				ds.Tables[0].Rows[numero]["Nombre"] = this.txtNombre.Text;
				ds.Tables[0].Rows[numero]["Apellidos"] = this.txtApellidos.Text;
				ds.Tables[0].Rows[numero]["Usuario"] = this.txtUser.Text;
				ds.Tables[0].Rows[numero]["Pasoteword"] = this.txtPassword.Text;
				ds.Tables[0].Rows[numero]["TipoID"] = this.cmbTipoUsuario.SelectedIndex+1;
			ds.Tables[0].Rows[numero].EndEdit();
			}catch(Exception ex){
				FM_Errores.MostrarError("GuardarRegistro","No se puede sincronizar el dataset con el formulario",ex);
			}
		}

		
		
		void BtnFirstClick(object sender, System.EventArgs e)
		{
			this.RecPosition = 0;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);			

		}
		
		void BtnPrevClick(object sender, System.EventArgs e)
		{
			if( this.RecPosition > 0)
			this.RecPosition--;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);

		}
		
		void BtnNextClick(object sender, System.EventArgs e)
		{
			if( this.RecPosition < this.RecCount-1)
			this.RecPosition++;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
	
		}
		
		void BtnLastClick(object sender, System.EventArgs e)
		{
			this.RecPosition = this.RecCount-1;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
		
		}
		
		void GuardarModificaciones()
		{
			try
    			{
        		int Modificaciones= 0; 

        			Modificaciones += adap.Update(ds,"Personal");
        			ds.Clear();
        			adap.Fill(ds,"Personal");
        			this.RecPosition=0;
        			this.RecCount = ds.Tables[0].Rows.Count;
        			this.CargarRegistro (this.RecPosition );
        			this.MostrarPosicion();
        			FM_Errores.MostrarAviso("Actualizacion correcta","Actualizados "+Modificaciones+" registros");
        			
				}catch (Exception ex){
					FM_Errores.MostrarError("Actualizacion","Error actualizando datos",ex);
        	    }
			
		}

		void BtnNuevoClick(object sender, System.EventArgs e)
		{
			int l; // Nivel para nuevo
			try{
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(52); // Modulo 5: Personal, accion 2:Nuevo
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar aadir datos de pacientes con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite aadir datos");
				return;
			}
			
			SecLocal.CreateNewUser("cambiar","cambiar","",1,"cambiar","cambiar","");

			ds.Clear();
        	adap.Fill(ds,"Personal");

			this.RecCount = ds.Tables[0].Rows.Count;
			this.RecPosition = this.RecCount-1;
			this.pctAvatar.Image = null;
			
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
			}catch(Exception ex){
				FM_Errores.MostrarError("PersonalMiniVista","No se ha podido aadir un nuevo registro",ex);
			}

		}
		
		void BtnGuardarClick(object sender, System.EventArgs e)
		{
			int l; // Nivel para guardar
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(53); // Modulo 5: Personal, accion 3: Modificar
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar modificar los datos de pacientes con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite modificar los datos");
				return;
			}
			
			GuardarRegistro(this.RecPosition);
			GuardarModificaciones();

		}
		
		void BtnImprimirListadoClick(object sender, System.EventArgs e)
		{
		if (MessageBox.Show("Desea imprimir los avatares?", "Pregunta impresin", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
			this.ImprimirListado(0,ds.Tables[0].Rows.Count,false);
		else
			this.ImprimirListado(0,ds.Tables[0].Rows.Count,true);
		}
		
		void BtnCerrarClick(object sender, System.EventArgs e)
		{
			this.Close();
		}
		
		void BtnCambiarClick(object sender, System.EventArgs e)
		{
			string newpasoteword;
			GenericInputForm inputbox = new GenericInputForm("Contrasea","Nueva Contrasea",'*');
			inputbox.ShowDialog();
			if(inputbox.result >0){
				newpasoteword = inputbox.answer;
				this.txtPassword.Text = SecLocal.ConvertiraMd5(newpasoteword);
			}
		}
		
		void BtnSelectClick(object sender, System.EventArgs e)
		{
			try{
				OpenFileDialog filed1 = new OpenFileDialog();
			
			filed1.Filter = "Mapas de bits|*.bmp|JPEG|*.jpg|JPEG|*.jpeg|GIF|*.gif";
			filed1.Title = "Elegir imagen";
			if (filed1.ShowDialog() != DialogResult.Cancel){
				ds.Tables[0].Rows[this.RecPosition]["Avatar"] = filed1.FileName;
				this.pctAvatar.Image = Image.FromFile(filed1.FileName);
			}
			}catch(Exception ex){
				FM_Errores.MostrarError("PersonalMiniVista","No se puede cargar-seleccionar la imagen",ex);
			}
		}
		private void ImprimirListado(int from, int dest, bool ava)
		{
			try{
			Formulacion.Impresiones docMaterial = new Formulacion.Impresiones();
			PrintPreviewDialog prevDialog = new PrintPreviewDialog();
			PrintDialog prdialog = new PrintDialog();
			
			docMaterial.ImprimirCabezera();
			docMaterial.NuevoTexto("Listado de Personal.");
			
			
			for(int i=from ; i<dest; ++i)
			{
			docMaterial.NuevaLinea();
			docMaterial.NuevoTexto("Personal ID: " + ds.Tables[0].Rows[i]["PersonalID"].ToString());
			docMaterial.NuevoTexto("Tipo Personal ID: " + ds.Tables[0].Rows[i]["TipoID"].ToString());
			docMaterial.NuevoTexto("Nombre: " + ds.Tables[0].Rows[i]["Nombre"].ToString());
			docMaterial.NuevoTexto("Apellidos: " + ds.Tables[0].Rows[i]["Apellidos"].ToString());
			docMaterial.NuevoTexto("Usuario: " + ds.Tables[0].Rows[i]["Usuario"].ToString());
			
			if( ava)
			{
				docMaterial.NuevoTexto("Avatar: ");
				docMaterial.NuevaImagen( ds.Tables[0].Rows[i]["Avatar"].ToString() );
			}

			
			docMaterial.NuevoTexto("");
			}
			
			prevDialog.Document = docMaterial;
			prdialog.Document = docMaterial;
			
			docMaterial.PrintPage += new PrintPageEventHandler(docMaterial.ImprimirElementos);
			docMaterial.BeginPrint += new PrintEventHandler (docMaterial.Reajustar);
			
			// Esto esta por ser configurable en fichero XML o DB
			// docMaterial.MuestraPrefsPagina();
			
			
			// Esto tambien deberia ser configurable
			prevDialog.Text = "Previsualizacion del listado personal";
			prevDialog.ShowDialog();
			
			if (prdialog.ShowDialog()== DialogResult.OK)
			{
				docMaterial.Print();
			}

			
			}catch(Exception ex){
				FM_Errores.MostrarError("Impresion","No se puede imprimir el listado",ex);
			}

		}

		
		
		
	}
}
